@@ -1,8 +1,10 @@
 /**
+ * vim: sw=4 ts=4:
+ *
  * Graphical .deb file viewer
  *
  * 	(C) 1998 Lalo Martins <lalo@debian.org>
- * 	    2002, 2003 Filip Van Raemdonck <mechanix@debian.org>
+ * 	    2002-2005 Filip Van Raemdonck <mechanix@debian.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -45,40 +47,38 @@ using namespace std;
 class NoPackage : public GDeb::Package
 {
 public:
-  // Stuff to display
-  virtual string Name() { return _("No package selected"); }
-  virtual string Version() { return ""; }
-  virtual string Description_Short()  { return ""; }
-  virtual string Description_Long()  { return ""; }
-  virtual string Section()  { return ""; }
-  virtual string Priority()  { return ""; }
-  virtual string Size()  { return ""; }
-  virtual string Installed_Size()  { return ""; }
-  virtual string Maintainer()  { return ""; }
-  virtual string Status()  { return ""; }
-  virtual string Current_Version()  { return ""; }
-  virtual string Architecture()  { return ""; }
-  virtual string Source()  { return ""; }
-  virtual string Filename()  { return ""; }
-	virtual string Filelist (void) { return ""; }
-	virtual string Author (void) { return ""; }
-	virtual string Homepage (void) { return ""; }
-  virtual bool   Essential() { return false; }
-  virtual bool   Downloadable() { return false; }
-  virtual bool   Automatic() { return false; }
-  virtual vector<string> Provides() { return vector<string>(0); }
-  virtual vector<string> PreDepends()  { return vector<string>(0); }
-  virtual vector<string> Depends()  { return vector<string>(0); }
-  virtual vector<string> Recommends()  { return vector<string>(0); }
-  virtual vector<string> Suggests()  { return vector<string>(0); }
-  virtual vector<string> Conflicts()  { return vector<string>(0); }
-  virtual vector<string> Replaces()  { return vector<string>(0); }
-  
-  // Actions - should not be called on a nopackage
-  virtual void Install() { g_warning(__FUNCTION__); }
-  virtual void Delete() { g_warning(__FUNCTION__); }
-  virtual void Keep() { g_warning(__FUNCTION__); }
+	string Name (void) { return _("No package selected"); }
+	string Version (void) { return ""; }
+	string Description_Short (void) { return ""; }
+	string Description_Long (void) { return ""; }
+	string Section (void) { return ""; }
+	string Priority (void) { return ""; }
+	string Size (void) { return ""; }
+	string Installed_Size (void) { return ""; }
+	string Maintainer (void) { return ""; }
+	string PackageStatus (void) { return ""; }
+	string Current_Version (void) { return ""; }
+	string Architecture (void) { return ""; }
+	string Source (void) { return ""; }
+	string Filename (void) { return ""; }
+	string Filelist (void) { return ""; }
+	string Author (void) { return ""; }
+	string Homepage (void) { return ""; }
+	bool Essential (void) { return false; }
+	bool Downloadable (void) { return false; }
+	bool Automatic (void) { return false; }
+	vector<string> Provides (void) { return vector<string>(0); }
+	vector<string> PreDepends (void) { return vector<string>(0); }
+	vector<string> Depends (void) { return vector<string>(0); }
+	vector<string> Recommends (void) { return vector<string>(0); }
+	vector<string> Suggests (void) { return vector<string>(0); }
+	vector<string> Conflicts (void) { return vector<string>(0); }
+	vector<string> Replaces (void) { return vector<string>(0); }
 
+	/* Actions - should not be called on a nopackage */
+	void Install (void) { g_warning (__FUNCTION__); }
+	void Delete (void) { g_warning (__FUNCTION__); }
+	void Keep (void) { g_warning (__FUNCTION__); }
 };
 
 static NoPackage* no_package = 0;
@@ -414,7 +414,7 @@ GDeb::refresh()
 
   if (status_ != 0)
     {
-      string s = p->Status();
+      string s = p->PackageStatus();
 		gtk_label_set_text (GTK_LABEL (status_), s.c_str());
     }
 
